@@ -3,7 +3,7 @@ package Perl::Critic::Freenode;
 use strict;
 use warnings;
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 1;
 
@@ -84,6 +84,10 @@ Don't use C<return> with no arguments
 
 Don't call methods indirectly
 
+=item L<Perl::Critic::Policy::Freenode::LoopOnHash>
+
+Don't loop over hashes
+
 =item L<Perl::Critic::Policy::Freenode::ModPerl>
 
 Don't use C<mod_perl> to write web applications
